SECIMTools project aims to develop a suite of tools for processing of metabolomics data, which can
be run in a standalone mode or via Galaxy Genomics Framework.

The SECIMTools a set of python tools that are available both as standalone and wrapped for use in
Galaxy. The suite includes a comprehensive set of quality control metrics (retention time window
evaluation and various peak evaluation tools), visualization techniques (hierarchical cluster
heatmap, principal component analysis, linear discriminant analysis, modular modularity
clustering), basic statistical analysis methods (partial least squares - discriminant analysis,
analysis of variance), advanced classification methods (random forest, support vector machines),
and advanced variable selection tools (least absolute shrinkage and selection operator LASSO and
Elastic Net).
